@@ -1,11 +1,9 @@
 import mig_create_short_cut
-from mstrio.object_management import search_operations
-from mstrio.api import browsing
 
 mig = mig_create_short_cut.open_conn()
-mig_rep=mig_create_short_cut.get_change_log()
-mig_short_cut=mig_create_short_cut.bld_short_cuts()
-cube_it=mig_create_short_cut.cubes()
+mig_rep= mig_create_short_cut.get_change_log()
+mig_short_cut= mig_create_short_cut.bld_short_cuts()
+cube_it= mig_create_short_cut.cubes()
 username = "Administrator"
 password ="Administrator"
 server="85.214.60.83"
